.. Weaviate Python Client documentation master file, created by
   sphinx-quickstart on Tue Apr 13 10:32:22 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Weaviate Python Client's documentation!
==================================================

.. raw:: html

    <img alt='Weaviate logo' src='https://raw.githubusercontent.com/semi-technologies/weaviate/19de0956c69b66c5552447e84d016f4fe29d12c9/docs/assets/weaviate-logo.png' width='180' align='right' />

.. image:: https://github.com/weaviate/weaviate-python-client/actions/workflows/.github/workflows/main.yaml/badge.svg?branch=main
    :target: https://github.com/weaviate/weaviate/actions/workflows/.github/workflows/pull_requests.yaml
    :alt: Build Status

.. image:: https://badge.fury.io/py/weaviate-client.svg
    :target: https://badge.fury.io/py/weaviate-client
    :alt: PyPI version

The Python client makes it easy to work with `Weaviate <https://weaviate.io/>`_. The client is tested for python 3.8 and higher.

There are two versions of the Weaviate Python client. The latest version, v4, is redesigned to take advantage of a faster query interface and offers improved programming features. For more information, see:

- `Python Client v4 overview <https://weaviate.io/developers/weaviate/client-libraries/python>`_
- `Python Client v3 overview <https://weaviate.io/developers/weaviate/client-libraries/python_v3>`_
- `Weaviate feature documentation and examples <https://weaviate.io/developers/weaviate>`_

Articles
--------

Here are some articles on Weaviate:

- `Semantic Search Queries Return More Informed Results <https://hackernoon.com/semantic-search-queries-return-more-informed-results-nr5335nw>`_
- `Getting Started with Weaviate Python Library <https://towardsdatascience.com/getting-started-with-weaviate-python-client-e85d14f19e4f>`_
- `A sub-50ms neural search with DistilBERT and Weaviate <https://towardsdatascience.com/a-sub-50ms-neural-search-with-distilbert-and-weaviate-4857ae390154>`_

Support
-------

- Use our `Forum <https://forum.weaviate.io>`_ for support or any other question.
- Use our `Slack Channel <https://weaviate.io/slack>`_ for discussions or any other question.
- Use the ``weaviate`` tag on `StackOverflow <https://stackoverflow.com/questions/tagged/weaviate>`_  for questions.
- For bugs or problems, submit a GitHub `issue <https://github.com/weaviate/weaviate-python-client/issues>`_.


.. COMMENT: Generates index page

Method Index
------------

* :ref:`genindex`

.. COMMENT: Creates left hand Table of contents

.. toctree::
   :maxdepth: 2
   :hidden:

   weaviate
   changelog
   genindex
